@@ -44,3 +44,12 @@ auto_by_msg <- function(by) {
 
   paste0("Matching, by = ", by_code)
 }
+
+# from https://github.com/r-lib/cli/blob/main/R/tree.R
+box_chars <- function() {
+  if (cli::is_utf8_output()) {
+    list(h = "\u2500", v = "\u2502", l = "\u2514", j = "\u251C")
+  } else {
+    list(h = "-", v = "|", l = "\\", j = "+")
+  }
+}
